import React from 'react';
import * as echarts from 'echarts/core';
import Chart from '@/components/chart';
import { getUserEdu } from '@/services/statis';

export default (props) => {

  const [option, setOption] = React.useState({});

  React.useEffect(() => {
    getUserEdu().then(res => {
      const keys = (res || []).map(x => x.name);
      const vals = (res || []).map(x => x.cnt);
      setOption(getOption(keys, vals));
    });
  }, [])

  return (
    <Chart option={option} style={{ height: '300px' }} />
  )
}

function getOption(yAxisData, seriesData) {
  var maxValue = seriesData.slice().sort().reverse()[0] - 0 + 10

  var title = {
    show: true,
    top: '6%',
    left: 'center',
    text: '人员学历统计',
    textStyle: {
      color: '#fff',
      fontSize: 18,
      fontWeight: 'normal'
    }
  }

  // 实际上是绘制了 seriesData.length 个的柱图
  var percent = 100 / seriesData.length
  var grid = seriesData.map(function (_, index) {
    return {
      top: (20 + index * 20 ) + '%',
      height: percent + '%',
    }
  })

  var xAxis = seriesData.map(function (_, index) {
    return { type: 'value', show: false, gridIndex: index }
  })

  var yAxis = yAxisData.map(function(_, index) {
    return {
      type: 'category',
      position: 'right',
      gridIndex: index,
      axisLine: { show: false },
      axisTick: { show: false },
      axisLabel: {
        color: '#fff',
        fontSize: 16,
        formatter: function () {
          return seriesData[index];
        }
      }
    }
  })

  var colors = [
    new echarts.graphic.LinearGradient(0, 0, 1, 0, [
      { offset: 0, color: '#87E8C5' },
      { offset: 1, color: '#15E096' }
    ]),
    new echarts.graphic.LinearGradient(0, 0, 1, 0, [
      { offset: 0, color: '#00BFFA' },
      { offset: 1, color: '#0160EB' }
    ]),
    new echarts.graphic.LinearGradient(0, 0, 1, 0, [
      { offset: 0, color: '#FFBE4E' },
      { offset: 1, color: '#F77C30' }
    ]),
  ]

  var barGaps = []; // 用来做背景
  var pictorialBar = []; // 尾部的圆
  var series = seriesData.map(function(dt, index) {
    barGaps.push({
      type: 'bar',
      silent: true,
      name: yAxisData[index],
      xAxisIndex: index,
      yAxisIndex: index,
      barWidth: 16,
      barGap: '-180%',
      data: [maxValue],
      label: {
        show: true,
        position: [0, '-160%'],
        formatter: '{a}',
        color: '#fff',
        fontSize: 16,
      },
      itemStyle: {
        color: 'rgba(255, 255, 255, 0.05)',
        borderColor: 'rgba(255, 255, 255, 0.2)',
        borderWidth: 1
      }
    })

    pictorialBar.push({
      silent: true,
      type: 'pictorialBar',
      xAxisIndex: index,
      yAxisIndex: index,
      data: [dt],
      symbol: 'circle',
      symbolSize: [10, 10],
      symbolPosition: 'end',
      symbolOffset: ['50%', '-25%'],
    })

    return {
      data: [dt],
      type: 'bar',
      barWidth: 6,
      xAxisIndex: index,
      yAxisIndex: index,
    }
  })

  var option = {
    title: title,
    xAxis: xAxis,
    yAxis: yAxis,
    grid: grid,
    color: colors,
    series: series.concat(barGaps).concat(pictorialBar)
  }

  // console.log(option)
  return option
}